SystemOrganization addCategory: #FuelProgressUpdate!
SystemOrganization addCategory: #'FuelProgressUpdate-Tests'!

FLSerializer subclass: #FLProgressUpdaterSerializer
	instanceVariableNames: 'progressHandler progressBarFactory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLProgressUpdaterSerializer commentStamp: 'MartinDias 4/28/2011 15:30' prior: 0!
I am a serializer that inform progress during the serialization.

With the message #serialize:analyzer:analysisCheckpoints:, I introduce a new parameter to the serialization, called the *analysisCheckpoints*. It is a collection whose elements are the only objects that will produce progress increments during the dependency graph analysis, that is done in the first part of the serialization process. See the example below.

Now, an example of use, serializing 2^14 points. 

	| objectToSerialize analysisCheckpoints run |
	objectToSerialize := (1 to: 1 << 14) collect: [ :i | i @ (i+1) ].
	analysisCheckpoints := 1 to: 1 << 14.
	(FLProgressUpdaterSerializer example)
		serialize: objectToSerialize
		analyzer: FLProgressUpdaterSerializer defaultAnalyzer
		analysisCheckpoints: analysisCheckpoints.


Note: In the method #defaultProgressBarFactory is defined the default way of displaying progress. It is possible to change it using #progressBarFactory:.

!

!FLProgressUpdaterSerializer classSide methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:52'!
defaultAnalyzer

	^ FLProgressUpdaterAnalyzer newDefault! !

!FLProgressUpdaterSerializer classSide methodsFor: 'accessing' stamp: 'MartinDias 4/29/2011 07:20'!
defaultProgressBarFactory

	self flag: #todo. "this is horrible"
	^ [ :aBlockThatNotifiesToProgressHandler | 
		'Writing to stream' 
			displayProgressAt: Sensor cursorPoint 
			from: 0 
			to: 100 
			during: [ :aBlockToValueWithProgressUpdates | 
				aBlockThatNotifiesToProgressHandler 
					value: (FLDefaultSerializationProgressHandler progressBlock: aBlockToValueWithProgressUpdates) ] ]
! !

!FLProgressUpdaterSerializer methodsFor: 'initialize-release' stamp: 'MartinDias 4/29/2011 06:56'!
initialize 

	super initialize.
	progressBarFactory := self class defaultProgressBarFactory.
	progressHandler := FLNullSerializationProgressHandler new.! !

!FLProgressUpdaterSerializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 10:21'!
progressBarFactory
	^ progressBarFactory! !

!FLProgressUpdaterSerializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 10:21'!
progressBarFactory: anObject
	progressBarFactory := anObject! !

!FLProgressUpdaterSerializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 10:21'!
progressHandler
	^ progressHandler! !

!FLProgressUpdaterSerializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 10:21'!
progressHandler: anObject
	progressHandler := anObject! !

!FLProgressUpdaterSerializer methodsFor: 'serializing' stamp: 'MartinDias 4/28/2011 10:18'!
serialize: anObject 
	"Serializes using the default analyzer"

	self serialize: anObject analyzer: self class defaultAnalyzer! !

!FLProgressUpdaterSerializer methodsFor: 'serializing' stamp: 'MartinDias 4/28/2011 12:21'!
serialize: anObject analyzer: anAnalyzer
	"The behavior is the inherited but showing a progress bar"

	^ self serialize: anObject analyzer: anAnalyzer analysisCheckpoints: (Array with: anObject)! !

!FLProgressUpdaterSerializer methodsFor: 'serializing' stamp: 'MartinDias 4/29/2011 06:44'!
serialize: anObject analyzer: anAnalyzer analysisCheckpoints: aCollection

	self progressBarFactory
		value: [ :aProgressHandler | 
			self progressHandler: aProgressHandler.
			anAnalyzer progressHandler: self progressHandler.
			
			self progressHandler analysisBegin: aCollection.
			super serialize: anObject analyzer: anAnalyzer.
			self progressHandler serializationEnd. ]! !

!FLProgressUpdaterSerializer methodsFor: 'serializing' stamp: 'MartinDias 5/30/2011 16:34'!
serializeCluster: aCluster objects: aCollection

	super serializeCluster: aCluster objects: aCollection.
	self progressHandler serializedCluster: aCluster objects: aCollection! !

!FLProgressUpdaterSerializer methodsFor: 'serializing' stamp: 'MartinDias 4/28/2011 11:31'!
serializeHeaderWith: clusteredObjects and: objectCount

	self progressHandler serializationBegin: clusteredObjects and: objectCount.  
	super serializeHeaderWith: clusteredObjects and: objectCount.! !

!FLSerializer class methodsFor: '*FuelProgressUpdate' stamp: 'MartinDias 4/28/2011 15:48'!
example

	^ self on: (RWBinaryOrTextStream on: '') binary! !

FLAnalyzer subclass: #FLProgressUpdaterAnalyzer
	instanceVariableNames: 'progressHandler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLProgressUpdaterAnalyzer commentStamp: 'MartinDias 4/28/2011 15:32' prior: 0!
I am an analyzer that inform progress during the dependency graph iteration, in the first part of the serialization process.
!

!FLProgressUpdaterAnalyzer methodsFor: 'initialize-release' stamp: 'MartinDias 4/29/2011 06:38'!
initialize 

	super initialize.
	progressHandler := FLNullSerializationProgressHandler new.! !

!FLProgressUpdaterAnalyzer methodsFor: 'analyze' stamp: 'MartinDias 5/31/2011 18:44'!
mapAndTrace: anObject

	progressHandler analyzedObject: anObject. 
	super mapAndTrace: anObject.! !

!FLProgressUpdaterAnalyzer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 10:42'!
progressHandler
	^ progressHandler! !

!FLProgressUpdaterAnalyzer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 10:42'!
progressHandler: anObject
	progressHandler := anObject! !

TestCase subclass: #FLProgressUpdaterMaterializerTest
	instanceVariableNames: 'progressUpdateRecorder analyzer serializer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLProgressUpdaterMaterializerTest methodsFor: 'tests' stamp: 'MartinDias 4/28/2011 15:36'!
assertProgressUpdates

	self
		assert: self minimumNumberOfProgressUpdates <= progressUpdateRecorder progressUpdates size
		description: 'There is a minimum of progress updates that should happen during the serialization'.
	self
		deny: progressUpdateRecorder progressUpdates hasAnyDuplicate
		description: 'The bar should not update more than once to the same progress value'.
	self 
		assert: progressUpdateRecorder progressUpdates isSorted 
		description: 'The bar should always increment its progress'.
	self 
		assert: 100 = progressUpdateRecorder progressUpdates last 
		description: 'The last update should be 100%'! !

!FLProgressUpdaterMaterializerTest methodsFor: 'running' stamp: 'MartinDias 4/28/2011 15:39'!
minimumNumberOfProgressUpdates
	"The progress bar should advance at least when cluster materializes."
	
	^ analyzer clusteredObjects size! !

!FLProgressUpdaterMaterializerTest methodsFor: 'running' stamp: 'MartinDias 4/29/2011 07:18'!
recorderProgressBarFactory

	self flag: #todo. "This is horrible"
	^ [ :aBlockThatNotifiesToProgressHandler | 
		progressUpdateRecorder recordProgressUpdatesDuring: [ :aBlockToValueWithProgressUpdates | 
			aBlockThatNotifiesToProgressHandler value: (FLMaterializationProgressHandler progressBlock: aBlockToValueWithProgressUpdates). ] ]! !

!FLProgressUpdaterMaterializerTest methodsFor: 'tests' stamp: 'MartinDias 4/29/2011 07:19'!
serializeAndMaterialize: anObject

	| materializer |
	serializer serialize: anObject analyzer: analyzer.
	materializer := FLProgressUpdaterMaterializer on: serializer stream reset.
	materializer progressBarFactory: self recorderProgressBarFactory.
	materializer materialize.
 ! !

!FLProgressUpdaterMaterializerTest methodsFor: 'running' stamp: 'MartinDias 4/28/2011 16:02'!
setUp

	super setUp.
	progressUpdateRecorder := FLProgressUpdateRecorder new.
	analyzer := FLAnalyzer newDefault.
	serializer := FLSerializer example.
! !

!FLProgressUpdaterMaterializerTest methodsFor: 'tests' stamp: 'MartinDias 4/28/2011 16:46'!
testCharacter

	self serializeAndMaterialize: $A.
	self assertProgressUpdates! !

!FLProgressUpdaterMaterializerTest methodsFor: 'tests' stamp: 'MartinDias 4/28/2011 15:46'!
testRectangle

	self serializeAndMaterialize: (1@2 corner: 3@4).
	self assertProgressUpdates! !

TestCase subclass: #FLProgressUpdaterSerializerTest
	instanceVariableNames: 'analyzer serializer object progressUpdateRecorder analysisCheckpoints'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLProgressUpdaterSerializerTest methodsFor: 'tests' stamp: 'MartinDias 4/28/2011 12:58'!
assertProgressUpdates

	self
		assert: self minimumNumberOfProgressUpdates <= progressUpdateRecorder progressUpdates size
		description: 'There is a minimum of progress updates that should happen during the serialization'.
	self
		deny: progressUpdateRecorder progressUpdates hasAnyDuplicate
		description: 'The bar should not update more than once to the same progress value'.
	self 
		assert: progressUpdateRecorder progressUpdates isSorted 
		description: 'The bar should always increment its progress'.
	self 
		assert: 100 = progressUpdateRecorder progressUpdates last 
		description: 'The last update should be 100%'! !

!FLProgressUpdaterSerializerTest methodsFor: 'running' stamp: 'MartinDias 4/28/2011 12:57'!
minimumNumberOfProgressUpdates
	"The progress bar should advance at least when a checkpoint is analyzed and when a cluster serializes"
	
	^ analysisCheckpoints size + analyzer clusteredObjects size! !

!FLProgressUpdaterSerializerTest methodsFor: 'running' stamp: 'MartinDias 4/29/2011 07:18'!
recorderProgressBarFactory

	self flag: #todo. "This is horrible"
	^ [ :aBlockThatNotifiesToProgressHandler | 
		progressUpdateRecorder recordProgressUpdatesDuring: [ :aBlockToValueWithProgressUpdates | 
			aBlockThatNotifiesToProgressHandler value: (FLDefaultSerializationProgressHandler progressBlock: aBlockToValueWithProgressUpdates). ] ]! !

!FLProgressUpdaterSerializerTest methodsFor: 'running' stamp: 'MartinDias 4/29/2011 07:15'!
setUp

	super setUp.
	analyzer := FLProgressUpdaterSerializer defaultAnalyzer.
	serializer := FLProgressUpdaterSerializer example.
	progressUpdateRecorder := FLProgressUpdateRecorder new.
	serializer progressBarFactory: self recorderProgressBarFactory.! !

!FLProgressUpdaterSerializerTest methodsFor: 'tests' stamp: 'MartinDias 4/29/2011 06:28'!
testAnalyzerIgnoresProgressUpdateWhenWorksAlone
	"Some re-design en serializer has to be done, it is strange that a behavior like this is needed."

	object := #(1 2 3 4).

	self shouldnt: [ analyzer analyze: object ] raise: Error.
! !

!FLProgressUpdaterSerializerTest methodsFor: 'tests' stamp: 'MartinDias 4/28/2011 15:33'!
testOneCheckpoint

	object := 1@2 corner: 3@4.
	analysisCheckpoints := Array with: object.

	serializer serialize: object analyzer: analyzer analysisCheckpoints: analysisCheckpoints.

	self assertProgressUpdates! !

!FLProgressUpdaterSerializerTest methodsFor: 'tests' stamp: 'MartinDias 4/28/2011 15:34'!
testRectangle

	object := 1@2 corner: 3@4.
	analysisCheckpoints := #(1 2 3 4).

	serializer serialize: object analyzer: analyzer analysisCheckpoints: analysisCheckpoints.

	self assertProgressUpdates! !

!FLProgressUpdaterSerializerTest methodsFor: 'tests' stamp: 'MartinDias 4/28/2011 15:35'!
testSmallIntegers

	object := #(1 2 3 4).
	analysisCheckpoints := #(1 2 3 4).

	serializer serialize: object analyzer: analyzer analysisCheckpoints: analysisCheckpoints.

	self assertProgressUpdates! !

!FLMaterializer methodsFor: '*FuelProgressUpdate' stamp: 'MartinDias 4/28/2011 16:10'!
clusterCount

	^clusterCount ! !

!FLMaterializer methodsFor: '*FuelProgressUpdate' stamp: 'MartinDias 4/28/2011 16:36'!
materializedInstances

	^materializedInstances! !

FLMaterializer subclass: #FLProgressUpdaterMaterializer
	instanceVariableNames: 'progressHandler progressBarFactory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLProgressUpdaterMaterializer commentStamp: 'MartinDias 4/28/2011 16:53' prior: 0!
I am a materializer that inform progress during the materialization process.

Now, an example of use, serializing and materializing 2^14 rectangles. 

	| serializer objectToSerialize |
	objectToSerialize := (1 to: 1 << 14) collect: [ :i | i @ (i+1) corner: (i+2) @ (i+3) ].
	serializer := FLSerializer example.
	serializer serialize: objectToSerialize.
	(FLProgressUpdaterMaterializer on: serializer stream reset) materialize.


Note: In the method #defaultProgressBarFactory is defined the default way of displaying progress. It is possible to change it using #progressBarFactory:.

!

!FLProgressUpdaterMaterializer classSide methodsFor: 'accessing' stamp: 'MartinDias 4/29/2011 07:20'!
defaultProgressBarFactory

	self flag: #todo. "this is horrible"
	^ [ :aBlockThatNotifiesToProgressHandler | 
		'Reading from stream' 
			displayProgressAt: Sensor cursorPoint 
			from: 0 
			to: 100 
			during: [ :aBlockToValueWithProgressUpdates | 
				aBlockThatNotifiesToProgressHandler 
					value: (FLMaterializationProgressHandler progressBlock: aBlockToValueWithProgressUpdates) ] ]
! !

!FLProgressUpdaterMaterializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:15'!
addAllMaterialized: aCollection
	
	super addAllMaterialized: aCollection.
	self progressHandler materializedObjects: aCollection.! !

!FLProgressUpdaterMaterializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:16'!
addMaterialized: anObject
	
	super addMaterialized: anObject.
	self progressHandler materializedObject: anObject.! !

!FLProgressUpdaterMaterializer methodsFor: 'initialize-release' stamp: 'MartinDias 4/28/2011 16:05'!
initialize 

	super initialize.
	progressBarFactory := self class defaultProgressBarFactory.! !

!FLProgressUpdaterMaterializer methodsFor: 'materializing' stamp: 'MarianoMartinezPeck 6/4/2011 14:44'!
materialize

	self progressBarFactory
		value: [ :aProgressHandler | 
			self progressHandler: aProgressHandler.
			super materialize.
			self progressHandler materializationEnd ].
		
	^ self root
		
		
! !

!FLProgressUpdaterMaterializer methodsFor: 'private' stamp: 'MartinDias 4/28/2011 16:32'!
materializeCluster

	super materializeCluster.
	self progressHandler materializedCluster.! !

!FLProgressUpdaterMaterializer methodsFor: 'private' stamp: 'MartinDias 4/28/2011 16:37'!
materializeHeader

	super materializeHeader.
	self progressHandler materializationBegin: materializedInstances capacity.! !

!FLProgressUpdaterMaterializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:04'!
progressBarFactory
	^ progressBarFactory! !

!FLProgressUpdaterMaterializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:04'!
progressBarFactory: anObject
	progressBarFactory := anObject! !

!FLProgressUpdaterMaterializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:04'!
progressHandler
	^ progressHandler! !

!FLProgressUpdaterMaterializer methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:04'!
progressHandler: anObject
	progressHandler := anObject! !

Object subclass: #FLMaterializationProgressHandler
	instanceVariableNames: 'materializingEstimatedPercentage progressBlock numberOfObjectsAlreadyMaterialized numberOfObjectsToMaterialize'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLMaterializationProgressHandler commentStamp: 'MartinDias 4/28/2011 16:47' prior: 0!
My job is to estimate a percentage of completeness of a materialization run. I am a collaborator of FLProgressUpdaterMaterializer.!

!FLMaterializationProgressHandler classSide methodsFor: 'instance creation' stamp: 'MartinDias 4/28/2011 16:22'!
progressBlock: aBlock

	^self basicNew
		initialize;
		progressBlock: aBlock;
		materializingEstimatedPercentage: 90;    
		yourself.! !

!FLMaterializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:40'!
materializationBegin: objectCount

	numberOfObjectsAlreadyMaterialized := 0.
	numberOfObjectsToMaterialize := objectCount.
	progressBlock value: 0! !

!FLMaterializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:41'!
materializationEnd
	
	progressBlock value: 100! !

!FLMaterializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:40'!
materializedCluster
	
	progressBlock value: self progressMaterializing! !

!FLMaterializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:39'!
materializedObject: anObject 

	numberOfObjectsAlreadyMaterialized := numberOfObjectsAlreadyMaterialized + 1! !

!FLMaterializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:41'!
materializedObjects: aCollection 

	numberOfObjectsAlreadyMaterialized := numberOfObjectsAlreadyMaterialized + aCollection size! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:23'!
materializingEstimatedPercentage
	^ materializingEstimatedPercentage! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:23'!
materializingEstimatedPercentage: anObject
	materializingEstimatedPercentage := anObject! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:25'!
numberOfObjectsAlreadyMaterialized
	^ numberOfObjectsAlreadyMaterialized! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:25'!
numberOfObjectsAlreadyMaterialized: anObject
	numberOfObjectsAlreadyMaterialized := anObject! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:25'!
numberOfObjectsToMaterialize
	^ numberOfObjectsToMaterialize! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:25'!
numberOfObjectsToMaterialize: anObject
	numberOfObjectsToMaterialize := anObject! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:23'!
progressBlock
	^ progressBlock! !

!FLMaterializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:23'!
progressBlock: anObject
	progressBlock := anObject! !

!FLMaterializationProgressHandler methodsFor: 'private' stamp: 'MartinDias 4/28/2011 16:28'!
progressMaterializing

	^ materializingEstimatedPercentage * numberOfObjectsAlreadyMaterialized / numberOfObjectsToMaterialize! !

Object subclass: #FLProgressUpdateRecorder
	instanceVariableNames: 'progressUpdates'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLProgressUpdateRecorder methodsFor: 'initialize-release' stamp: 'MartinDias 4/27/2011 21:40'!
initialize

	super initialize.
	progressUpdates := OrderedCollection new.! !

!FLProgressUpdateRecorder methodsFor: 'accessing' stamp: 'MartinDias 4/27/2011 21:40'!
progressUpdates
	^ progressUpdates! !

!FLProgressUpdateRecorder methodsFor: 'accessing' stamp: 'MartinDias 4/27/2011 21:40'!
progressUpdates: anObject
	progressUpdates := anObject! !

!FLProgressUpdateRecorder methodsFor: 'evaluating' stamp: 'MartinDias 4/28/2011 12:59'!
recordProgressUpdatesDuring: workingBlock

	workingBlock value: [ :progress | progressUpdates add: progress ]! !

Object subclass: #FLSerializationProgressHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLSerializationProgressHandler commentStamp: 'MartinDias 4/29/2011 07:03' prior: 0!
My job is to estimate a percentage of completeness of a serialization run. I am a collaborator of FLProgressUpdaterSerializer.!

FLSerializationProgressHandler subclass: #FLDefaultSerializationProgressHandler
	instanceVariableNames: 'progressBlock analyzingEstimatedPercentage serializingEstimatedPercentage numberOfObjectsToSerialize numberOfObjectsAlreadySerialized analysisCheckpoints remainingAnalysisCheckpoints'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLDefaultSerializationProgressHandler commentStamp: 'MartinDias 4/28/2011 16:47' prior: 0!
My job is to estimate a percentage of completeness of a serialization run. I am a collaborator of FLProgressUpdaterSerializer.!

!FLDefaultSerializationProgressHandler classSide methodsFor: 'instance creation' stamp: 'MartinDias 4/28/2011 12:01'!
progressBlock: aBlock

	^self basicNew
		initialize;
		progressBlock: aBlock;
		analyzingEstimatedPercentage: 70;
		serializingEstimatedPercentage: 20;    
		yourself.! !

!FLDefaultSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 12:21'!
analysisBegin: aCollection

	analysisCheckpoints := aCollection.
	remainingAnalysisCheckpoints := IdentitySet newFrom: aCollection.
	progressBlock value: 0! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
analysisCheckpoints
	^ analysisCheckpoints! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
analysisCheckpoints: anObject
	analysisCheckpoints := anObject! !

!FLDefaultSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 12:06'!
analyzedObject: anObject 

	remainingAnalysisCheckpoints
		remove: anObject
		ifAbsent: [ ^self ].
	progressBlock value: self progressAnalyzing.! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
analyzingEstimatedPercentage
	^ analyzingEstimatedPercentage! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
analyzingEstimatedPercentage: anObject
	analyzingEstimatedPercentage := anObject! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
numberOfObjectsAlreadySerialized
	^ numberOfObjectsAlreadySerialized! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
numberOfObjectsAlreadySerialized: anObject
	numberOfObjectsAlreadySerialized := anObject! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
numberOfObjectsToSerialize
	^ numberOfObjectsToSerialize! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
numberOfObjectsToSerialize: anObject
	numberOfObjectsToSerialize := anObject! !

!FLDefaultSerializationProgressHandler methodsFor: 'private' stamp: 'MartinDias 4/28/2011 12:05'!
progressAnalyzing

	^ analyzingEstimatedPercentage * (1 - ((remainingAnalysisCheckpoints size + 1) / (analysisCheckpoints size + 1)))! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
progressBlock
	^ progressBlock! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
progressBlock: anObject
	progressBlock := anObject! !

!FLDefaultSerializationProgressHandler methodsFor: 'private' stamp: 'MartinDias 4/28/2011 11:41'!
progressSerializing

	^ analyzingEstimatedPercentage + (serializingEstimatedPercentage * numberOfObjectsAlreadySerialized / numberOfObjectsToSerialize)! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
remainingAnalysisCheckpoints
	^ remainingAnalysisCheckpoints! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
remainingAnalysisCheckpoints: anObject
	remainingAnalysisCheckpoints := anObject! !

!FLDefaultSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 11:41'!
serializationBegin: clusteredObjects and: objectCount

	numberOfObjectsToSerialize := objectCount.
	numberOfObjectsAlreadySerialized := 0.
	progressBlock value: self progressSerializing.! !

!FLDefaultSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 11:25'!
serializationEnd

	progressBlock value: 100.! !

!FLDefaultSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 5/30/2011 16:30'!
serializedCluster: aCluster objects: aCollection

	numberOfObjectsAlreadySerialized := numberOfObjectsAlreadySerialized + aCollection size.
	progressBlock value: self progressSerializing.! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
serializingEstimatedPercentage
	^ serializingEstimatedPercentage! !

!FLDefaultSerializationProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
serializingEstimatedPercentage: anObject
	serializingEstimatedPercentage := anObject! !

FLSerializationProgressHandler subclass: #FLNullSerializationProgressHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLNullSerializationProgressHandler commentStamp: 'MartinDias 4/29/2011 07:04' prior: 0!
I represent the null implementation for handling serialization progress updates.!

!FLNullSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:36'!
analysisBegin: aCollection
! !

!FLNullSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:36'!
analyzedObject: anObject
	! !

!FLNullSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:36'!
serializationBegin: clusteredObjects and: objectCount
	! !

!FLNullSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:37'!
serializationEnd
	! !

!FLNullSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 5/30/2011 16:30'!
serializedCluster: aCluster objects: aCollection
	! !

!FLSerializationProgressHandler classSide methodsFor: 'instance creation' stamp: 'MartinDias 4/29/2011 06:32'!
progressBlock: aBlock

	^self basicNew
		initialize;
		progressBlock: aBlock;
		analyzingEstimatedPercentage: 70;
		serializingEstimatedPercentage: 20;    
		yourself.! !

!FLSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:34'!
analysisBegin: aCollection

	self subclassResponsibility ! !

!FLSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:34'!
analyzedObject: anObject 

	self subclassResponsibility ! !

!FLSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:34'!
serializationBegin: clusteredObjects and: objectCount

	self subclassResponsibility ! !

!FLSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:34'!
serializationEnd

	self subclassResponsibility ! !

!FLSerializationProgressHandler methodsFor: 'progress handling' stamp: 'MartinDias 5/30/2011 16:31'!
serializedCluster: aCluster objects: aCollection

	self subclassResponsibility ! !
